(* Delphi Unit
   strings of several units
   *** English version
      
    Dr. J. Rathlev, D-24222 Schwentinental (info(a)rathlev-home.de)

   The contents of this file may be used under the terms of the
   Mozilla Public License ("MPL") or
   GNU Lesser General Public License Version 2 or later (the "LGPL")

   Software distributed under this License is distributed on an "AS IS" basis,
   WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
   the specific language governing rights and limitations under the License.

   Vers. 1 - Dec. 2011
   *)

unit UnitStrings;

interface

{ ------------------------------------------------------------------- }
// Strings from FTPFileTools
function rsFtpConn : string;
function rsTryConnect : string;
function rsConnected : string;
function rsConnectErr : string;
function rsFtpHint : string;
function rsProxyHint : string;

// Strings from NumberUtil
function rsHexError : string;
function rsOctError : string;
function rsBinError : string;
function rsErrCopy : string;
function rsBytes : string;
function rsKBytes : string;
function rsMBytes : string;
function rsGBytes : string;
function rsUnknownError : string;
function rsWindowsError : string;
function rsStorageError : string;
function rsRpcError : string;
function rsInterfaceError : string;
function rsDispatchError : string;
function rsPreWin32Error : string;

function GetBytePrefixes : string;

// Strings from LangUtils
function rsSystemDefault : string;
function rsLangRestart : string;

// Strings from MathExp
function MathExpErrors (Error: Integer) : string;

// Strings from TextFilter
function rsIllRegExp : string;
function rsIllmask : string;

// Strings from WinExecute
function rsExecuteError : string;
function rsCreatePipeError : string;
function rsDupHandleError : string;
function rsCloseHandleError : string;

// Strings from CpDrv
function rsNoError : string;
function rsOpenError : string;
function rsStateError : string;
function rsFlushError : string;
function rsSetupError : string;

// Misc.
function rsVersion : string;
function rsLongCopyRight (const Year : string) : string;
function rsCopyRight (const Year : string) : string; overload;
function rsCopyRight : string; overload;
function rsNotAvail : string;
function rsConnectTo : string;
function rsUnknown : string;

implementation

uses System.SysUtils, System.DateUtils;

{ ------------------------------------------------------------------- }
// Strings from FTPFileTools
function rsFtpConn : string;    //'FTP-Verbindung';
begin
  Result:='FTP connection';
  end;

function rsTryConnect : string; //'Verbindung wird hergestellt';
begin
  Result:='Trying to connect to FTP server';
  end;

function rsConnected : string; //'Verbindung ist hergestellt';
begin
  Result:='Connection to FTP server established';
  end;

function rsConnectErr : string; //'Verbindung zu FTP-Server konnte nicht hergestellt werden!';
begin
  Result:='Connection to FTP server failed';
  end;

// Calling: Format(rsFtpHint,[host,port,user])
function rsFtpHint : string;
begin
  Result:='Connection to FTP server: %s:%u'+sLineBreak+'for user: %s'+sLineBreak+'requires a password!';
  end;

function rsProxyHint : string;
begin
  Result:='Connection to FTP proxy server: %s:%u'+sLineBreak+'for user: %s'+sLineBreak+'requires a password!';
  end;

{ ------------------------------------------------------------------- }
// Strings from NumberUtils
function rsHexError : string;
begin
  Result:='%s is not a valid hex value';    //'%s ist kein gltiger Hexwert';
  end;

function rsOctError : string;
begin
  Result:='&s is not a valid octal value';  //'%s ist kein gltiger Oktalwert';
  end;

function rsBinError : string;
begin
  Result:='&s is not a valid binary value'; //'%s ist kein gltiger Binrwert';
  end;

function rsErrCopy : string;
begin
  Result:='Error copying file to'+sLineBreak+'%s';        //'Fehler beim Kopieren von %';
  end;

function rsBytes : string;
begin
  Result:='B';
  end;

function rsKBytes : string;
begin
  Result:='kB';
  end;

function rsMBytes : string;
begin
  Result:='MB';
  end;

function rsGBytes : string;
begin
  Result:='GB';
  end;

// Strings from WinUtils
function rsUnknownError : string;
begin
  Result:='Unknown system error code';
  end;

function rsWindowsError : string;
begin
  Result:='Windows error';
  end;

function rsStorageError : string;
begin
  Result:='Storage error';
  end;

function rsRpcError : string;
begin
  Result:='Remote procedure call error'
  end;

function rsInterfaceError : string;
begin
  Result:='Interface error';
  end;

function rsDispatchError : string;
begin
  Result:='Dispatch error';
  end;

function rsPreWin32Error : string;
begin
  Result:='Error in SHFileOperation';
  end;

function GetBytePrefixes : string;
begin
  Result:='kMGT';
  end;

{ ------------------------------------------------------------------- }
// Strings from LangUtils
function rsSystemDefault : string;
begin
  Result:='&System default';
  end;

function rsLangRestart : string;
begin
  Result:='Changing language requires the program to be restarted!';
  end;

{ ------------------------------------------------------------------- }
// Strings from MathExp

function MathExpErrors (Error: Integer) : string;
begin
  case Error of
  0 : Result:= ' ';
  1 : Result:='Error (left/right parenthesis)'; //'Fehler (ffnende/schlieende Klammern)'
  2 : Result:='Input error (missing left parenthesis)'; //Eingabefehler (ffnende Klammer fehlt)';
  3 : Result:='Input error (empty parentheses)'; //'Eingabefehler (kein Klammerinhalt)';
  4 : Result:='Division by zero'; //'Division durch Null';
  5 : Result:='Invalid argument'; //'Unzulssiges Argument';
  6 : Result:='Overflow on operation'; //'Operation fhrt zu berlauf';
  7 : Result:='Invalid expression'; //'Unidentifizierbarer Ausdruck';
  8 : Result:='Unexpected operator'; //'Unerwartetes Operationssymbol';
  9 : Result:='Invalid expression'; //'Unvollstndiger Ausdruck';
  10 : Result:='Missing operator'; //'Operationssymbol fehlt';
  11 : Result:='Power with invalid (negative) base'; //'Potenz mit unzulssiger (negativer) Basis';
  12 : Result:='Zero to power of zero'; //'"Null hoch Null"';
  13 : Result:='Divide zero by zero'; //'"Null durch Null"';
  14 : Result:='Invalid combination of operands'; //'Unzulssige Kombination von Operanden';
  15 : Result:='Invalid character'; //'Unerlaubtes Zeichen';
  19 : Result:='Invalid argument (potential overflow)'; //'Unzulssiges Argument (berlaufgefahr)';
  20 : Result:='Low memory ("stack overflow")'; //'Speicherplatz fehlt ("stack overflow")';
  30 : Result:='Low memory ("string overflow")'; //'Speicherplatz fehlt ("string overflow")';
  else Result:='Unknown error'; //'Unbekannter Fehler';
    end;
  end;

{ ------------------------------------------------------------------- }
// Strings from TextFilter
function rsIllRegExp : string;
begin
  Result:='Illegal regular expression!'
  end;

function rsIllmask : string;
begin
  Result:='Illegal mask!'
  end;

{ ------------------------------------------------------------------- }
// Strings from WinExecute
function rsExecuteError : string;
begin
  Result:='Error executing process';
  end;

function rsCreatePipeError : string;
begin
  Result:='Stdout pipe creation failed';
  end;

function rsDupHandleError : string;
begin
  Result:='DuplicateHandle failed';
  end;

function rsCloseHandleError : string;
begin
  Result:='Closing handle failed';
  end;

{ ------------------------------------------------------------------- }
// Strings from CpDrv
function rsNoError : string;
begin
  Result:='No errors on COM connection';
  end;

function rsOpenError : string;
begin
  Result:='Error opening COM port';
  end;

function rsStateError : string;
begin
  Result:='Error setting COM port state';
  end;

function rsFlushError : string;
begin
  Result:='Error flushing COM buffers';
  end;

function rsSetupError : string;
begin
  Result:='Error initializing COM port';
  end;

{ ------------------------------------------------------------------- }
// Misc.
function rsVersion : string;
begin
  Result:='Version';
  end;

function rsLongCopyRight (const Year : string) : string;
begin
  Result:=' '+Year+' Dr. J. Rathlev'+sLineBreak+dgettext('units',' 24222 Schwentinental, Germany';
  end;

function rsCopyRight (const Year : string) : string;
begin
  Result:=' '+Year+' Dr. J. Rathlev';
  end;

function rsCopyRight : string;
begin
  rsCopyRight(IntToStr(YearOf(Now));
  end;

function rsNotAvail : string;
begin
  Result:='not available';
  end;

function rsConnectTo : string;
begin
  Result:='Connect to ..';
  end;

function rsUnknown : string;
begin
  Result:='<Unknown>';
  end;

{ ------------------------------------------------------------------- }
end.
